Python Library to access PS4
============================

|BuildStatus| |PypiVersion| |PyPiPythonVersions| |Coveralls| |CodeClimate|

Motivation
----------
The intention for this project is to have a pure python implementation of the `ps4-waker`_ features.

Tested with
-----------
PS 4 system version:

- 5.03 (05030061)
- 5.05 (05050031)
- 5.50 (05508011)

Credentials
-----------
Currently there is no way to generate the credential file with this library.
The credential file can be used from the ps4-waker.

References
----------

- https://github.com/dsokoloski/ps4-wake
- https://github.com/dhleong/ps4-waker

.. _ps4-waker: https://github.com/dhleong/ps4-waker


.. |BuildStatus| image:: https://travis-ci.org/hthiery/python-ps4.png?branch=master
                 :target: https://travis-ci.org/hthiery/python-ps4
.. |PyPiVersion| image:: https://badge.fury.io/py/pyps4.svg
                 :target: http://badge.fury.io/py/pyps4
.. |PyPiPythonVersions| image:: https://img.shields.io/pypi/pyversions/pyps4.svg
                        :alt: Python versions
                        :target: http://badge.fury.io/py/pyps4
.. |Coveralls|   image:: https://coveralls.io/repos/github/hthiery/python-ps4/badge.svg?branch=master
                 :target: https://coveralls.io/github/hthiery/python-ps4?branch=master
.. |CodeClimate| image:: https://api.codeclimate.com/v1/badges/193b80aebe76c6d8a2a2/maintainability
				 :target: https://codeclimate.com/github/hthiery/python-ps4/maintainability
				 :alt: Maintainability
